# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# fmt: off
from .....schema_classes import ContainerClass
from .....schema_classes import ContainerPropertiesClass
from .....schema_classes import EditableContainerPropertiesClass


Container = ContainerClass
ContainerProperties = ContainerPropertiesClass
EditableContainerProperties = EditableContainerPropertiesClass

# fmt: on
